pub struct MockReplacerControlMarker;Trait Implementations
Sourceimpl Clone for MockReplacerControlMarker
impl Clone for MockReplacerControlMarker
Sourcefn clone(&self) -> MockReplacerControlMarker
fn clone(&self) -> MockReplacerControlMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MockReplacerControlMarker
Sourceimpl Debug for MockReplacerControlMarker
impl Debug for MockReplacerControlMarker
Sourceimpl DiscoverableProtocolMarker for MockReplacerControlMarker
impl DiscoverableProtocolMarker for MockReplacerControlMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
impl Eq for MockReplacerControlMarker
Sourceimpl Hash for MockReplacerControlMarker
impl Hash for MockReplacerControlMarker
Sourceimpl Ord for MockReplacerControlMarker
impl Ord for MockReplacerControlMarker
Sourcefn cmp(&self, other: &MockReplacerControlMarker) -> Ordering
fn cmp(&self, other: &MockReplacerControlMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for MockReplacerControlMarker
impl PartialOrd for MockReplacerControlMarker
Sourceimpl ProtocolMarker for MockReplacerControlMarker
impl ProtocolMarker for MockReplacerControlMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.trf.mockcontrol.reversertrftest.MockReplacerControl"
const DEBUG_NAME: &'static str = "fuchsia.trf.mockcontrol.reversertrftest.MockReplacerControl"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = MockReplacerControlProxy
type Proxy = MockReplacerControlProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = MockReplacerControlRequestStream
type RequestStream = MockReplacerControlRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = MockReplacerControlSynchronousProxy
type SynchronousProxy = MockReplacerControlSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for MockReplacerControlMarker